%define maj  2
%define min  5
%define rel  12
%define rev  20051213

Summary:     The Squid proxy caching server
Name:        squid
Version:     %{maj}.%{min}.%{rel}.%{rev}
Release:     5.rh73.pp
Epoch:       10
License:     GPL
Group:       System Environment/Daemons
Source0:     http://www.%{name}-cache.org/Versions/v%{maj}/%{maj}.%{min}/%{name}-%{maj}.%{min}.STABLE%{rel}-%{rev}.tar.bz2
Source1:     %{name}.init
Source2:     %{name}.logrotate
Source3:     %{name}.sysconfig
Patch0:      %{name}-paths.patch
Patch1:      %{name}-config.patch
URL:         http://www.%{name}-cache.org/
Buildroot:   /var/tmp/%{name}-root
Vendor:      Duane Wessels <wessels@squid-cache.org>
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Provides:    %{name}.pp
Requires:    cyrus-sasl2 db4 openldap22 openssl097 pam perl procps
Prereq:      fileutils glibc shadow-utils
BuildPrereq: fileutils glibc-devel gcc make perl
BuildPrereq: cyrus-sasl2-devel db4-devel krb5-devel openldap22-devel
BuildPrereq: openssl097-devel pam-devel zlib-devel
ExclusiveOS: linux


%description
Squid is a high-performance proxy caching server for Web clients,
supporting FTP, gopher, and HTTP data objects. Unlike traditional
caching software, Squid handles all requests in a single, non-
blocking, I/O-driven process. Squid keeps meta data and especially
hot objects cached in RAM, caches DNS lookups, supports non-blocking
DNS lookups, and implements negative caching of failed requests.  


%prep
%setup -q -n %{name}-%{maj}.%{min}.STABLE%{rel}-%{rev}
%patch0 -p1 -b .paths
%patch1 -p1 -b .config
# Prepare docs
cp -f helpers/external_acl/ip_user/README README.ip_user
cp -f helpers/external_acl/unix_group/README README.unix_group
cp -f helpers/external_acl/ldap_group/README README.ldap_group
cp -f helpers/basic_auth/SMB/README README.SMB
cp -f helpers/basic_auth/LDAP/README README.LDAP
cp -f helpers/basic_auth/SASL/README README.SASL
rm -rf contrib/nextstep


%build
export CFLAGS="${RPM_OPT_FLAGS} -I/usr/kerberos/include"
export CPPFLAGS="-DMULTICAST_MISS_STREAM -DMULTICAST_MISS_TTL"
ulimit -HSn 32768
./configure \
	--prefix=%{_prefix}                         \
	--sysconfdir=%{_sysconfdir}/%{name}         \
	--libexecdir=%{_libexecdir}/%{name}         \
	--datadir=%{_datadir}/%{name}               \
	--localstatedir=%{_localstatedir}           \
	--mandir=%{_mandir}                         \
	--enable-dlmalloc                           \
	--enable-gnuregex                           \
	--enable-carp                               \
	--enable-async-io=64                        \
	--with-pthreads                             \
	--with-aio                                  \
	--with-dl                                   \
	--enable-storeio="aufs,coss,diskd,null,ufs" \
	--enable-removal-policies="heap,lru"        \
	--enable-icmp                               \
	--enable-delay-pools                        \
	--enable-useragent-log                      \
	--enable-referer-log                        \
	--enable-wccpv2                             \
	--enable-kill-parent-hack                   \
	--enable-snmp                               \
	--enable-arp-acl                            \
	--enable-htcp                               \
	--enable-ssl                                \
	--enable-forw-via-db                        \
	--enable-cache-digests                      \
	--disable-http-violations                   \
	--enable-linux-netfilter                    \
	--disable-ident-lookups                     \
	--enable-stacktraces                        \
	--enable-x-accelerator-vary                 \
	--enable-follow-x-forwarded-for             \
	--enable-auth="basic digest ntlm"           \
	--enable-digest-auth-helpers="password"     \
	--enable-ntlm-auth-helpers="SMB fakeauth no_check winbind"                 \
	--enable-basic-auth-helpers="LDAP MSNT NCSA PAM SASL SMB getpwnam winbind" \
	--enable-external-acl-helpers="ip_user ldap_group unix_group winbind_group"
# Fix path to perl
for file in `find . -type f -name *.pl -exec fgrep -l /bin/perl {} \;`; do
  cp -f $file tmpfile
  sed	-e 's+#!/user/local/bin/perl+#!%{__perl}+g' \
	-e 's+#!/usr/local/bin/perl+#!%{__perl}+g'  \
	-e 's+#!/bin/perl+#!%{__perl}+g' tmpfile > $file
  rm -f tmpfile
done
# Build
make all


# Do not strip, only compress documentation
%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}%{_initrddir}
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/{%{name},logrotate.d,sysconfig}
mkdir -p ${RPM_BUILD_ROOT}%{_prefix}
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/cache/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/log/%{name}/OLD
make \
	DESTDIR=${RPM_BUILD_ROOT} \
	install
install -m 0755 %{SOURCE1} ${RPM_BUILD_ROOT}%{_initrddir}/%{name}
install -m 0644 %{SOURCE2} ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}
install -m 0644 %{SOURCE3} ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{name}
chmod u+s ${RPM_BUILD_ROOT}%{_libexecdir}/%{name}/pinger
rm -f ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/squid.conf


%pre
if ! id -g %{name} > /dev/null 2>&1; then
  groupadd -r %{name}
fi
if ! id -u %{name} > /dev/null 2>&1; then
  useradd -g %{name} -G %{name}            \
	-d %{_localstatedir}/cache/%{name} \
	-r -s /sbin/nologin %{name}
fi


%post
if [ $1 = 1 ]; then
  chkconfig --add %{name}
  chkconfig %{name} on
fi
if [ -f %{_localstatedir}/lock/subsys/%{name} ]; then
  %{_initrddir}/%{name} restart
fi


%preun
if [ $1 = 0 ]; then
  chkconfig %{name} off
  chkconfig --del %{name}
  if [ -f %{_localstatedir}/lock/subsys/%{name} ]; then
    %{_initrddir}/%{name} stop
  fi
fi


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc ChangeLog CONTRIBUTORS COPYING COPYRIGHT CREDITS INSTALL
%doc QUICKSTART README* RELEASENOTES.html SPONSORS
%doc %dir contrib doc
%{_initrddir}/*
%config(noreplace) %{_sysconfdir}/logrotate.d/*
%config(noreplace) %{_sysconfdir}/sysconfig/*
%dir %attr(750,root,%{name}) %{_sysconfdir}/%{name}
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/*.conf
%{_sysconfdir}/%{name}/*.default
%{_bindir}/*
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/*
%{_sbindir}/*
%dir %{_datadir}/%{name}
%config(noreplace) %{_datadir}/%{name}/*
%{_mandir}/man8/*
%dir %attr(750,%{name},%{name}) %{_localstatedir}/cache/%{name}
%dir %attr(750,%{name},%{name}) %{_localstatedir}/log/%{name}
%dir %attr(750,%{name},%{name}) %{_localstatedir}/log/%{name}/OLD


%changelog
* Tue Dec 13 2005 peter.pramberger@member.fsf.org
- new version 2.5.STABLE12 (20051213)
- some spec file cleanups

* Fri Sep 09 2005 peter.pramberger@member.fsf.org
- new version 2.5.STABLE10 (20050909)

* Fri Aug 26 2005 peter.pramberger@member.fsf.org
- created

